package cn.wisenergy.service.app.impl;

import cn.wisenergy.common.utils.R;
import cn.wisenergy.model.enums.SceneType;
import cn.wisenergy.service.app.SendSmsSerVice;
import cn.wisenergy.service.cache.Cache;
import cn.wisenergy.service.common.CachePrefix;
import cn.wisenergy.service.common.Common;
import cn.wisenergy.service.util.SmsSign;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestClientException;
import org.springframework.web.client.RestTemplate;

/**
 * @author 86187
 * @ Description: 短信验证码接口实现
 * @ Author     : 86187
 * @ Date       : 2021/1/15 15:45
 */
@Service
@Slf4j
public class SendSmsSerViceImpl implements SendSmsSerVice {
    @Autowired
    private Cache cache;

    @Autowired
    private RestTemplate restTemplate;

    @Override
    public R<Boolean> sendSmCode(String phone) throws Exception {
        log.info("volunteer-service[]SendSmsSerViceImpl[]sendSmCode[]input.param.phone:" + phone);
        if (StringUtils.isBlank(phone)) {
            return R.error("入参不能为空!");
        }
        final HttpHeaders requestHeaders = new HttpHeaders();
        MediaType type = MediaType.parseMediaType("application/json; charset=UTF-8");
        requestHeaders.setContentType(type);

        String url = SmsSign.getUrl();
        log.info("完成路径："+url);
        String responseEntity = this.restTemplate.getForObject(url, String.class);

        return R.ok();
    }

    @Override
    public R<String> record(String phone, String code, Integer scene) {
        String value = SceneType.getNameByCode(scene);
        cache.put(CachePrefix.SMS_CODE.getPrefix() + value + "_" + phone, code, Common.SMS_TIMEOUT);
        return R.ok("缓存验证码成功!");
    }

    @Override
    public R<Boolean> valid(String phone, String code, Integer type) {
        String value = SceneType.getNameByCode(type);
        //获取短信验证码key
        String valCode = CachePrefix.SMS_CODE.getPrefix() + value + "_" + phone;
        //redis中获取验证码
        Object obj = cache.get(valCode);
        if (obj != null && obj.equals(code)) {
            //验证码存在，校验通过，清除验证码缓存
            cache.remove(valCode);
            return R.ok(0, true);
        }
        return R.ok(1, false);
    }

    @Override
    public boolean validCode(String phone, String code, Integer type) {
        return true;
//        //获取短信验证码key
//        String valCode = CachePrefix.SMS_CODE.getPrefix() + type + "_" + phone;
//        //redis中获取验证码
//        Object obj = cache.get(valCode);
//        if (obj != null && obj.equals(code)) {
//            //验证码存在，校验通过，清除验证码缓存
//            cache.remove(valCode);
//            return true;
//        }
//        return false;
    }


}
